#!/usr/bin/env node

let fs = require('fs');
let path = require('path');
let colors = require('colors');
let config;

if (fs.existsSync('./cliphpconf.json')) {
    config = require(process.cwd() + '/cliphpconf.json');
} else {
    config = require(path.resolve(__dirname, 'config.json'));
}

if (!fs.existsSync('./' + config.mainDir))
    return console.log('ERROR:'.red, config.mainDir + ' folder doesn\'t exists. To change the main folder to something else, define \'mainDir\' in the cliphpconf.json.');

if (!fs.existsSync('./' + config.mainDir + '/models'))
    return console.log('ERROR:'.red, config.mainDir + '/models' + ' folder doesn\'t exists');

if (!fs.existsSync('./' + config.mainDir + '/controllers'))
    return console.log('ERROR:'.red, config.mainDir + '/controllers' + ' folder doesn\'t exists');

if (!fs.existsSync('./' + config.mainDir + '/views') && config.generateView)
    return console.log('ERROR:'.red, config.mainDir + '/views' + ' folder doesn\'t exists');

createFile('model.php', 'Model.php', 'models');

if (config.generateView) {
    createFile('controllerwithview.php', 'Controller.php', 'controllers');
    createFile('view.php', 'View.php', 'views');
} else {
    createFile('controller.php', 'Controller.php', 'controllers');
}

function createFile(templateFile, fileEnding, destinationFolder) {
    fs.readFile(path.resolve(__dirname + '/templates', templateFile), function (err, data) {
        if (err) {
            console.log(err);
        } else {
            let output = data.toString().replace(new RegExp('classnameupper', 'g'), upperFirst(process.argv[2])).replace(new RegExp('classname', 'g'), process.argv[2]);
            fs.writeFile(config.mainDir + '/' + destinationFolder + '/' + process.argv[2] + fileEnding, output, function (err) {
                if (err) {
                    return console.log(err);
                } else {
                    console.log(`${process.argv[2]}${fileEnding}`.blue + ` created successfully`.green);
                }
            });
        }
    });
}

function upperFirst(string) {
    return string.charAt(0).toUpperCase() + string.slice(1);
}